@@ -16,8 +16,8 @@ freebsd-5.3/rpldev.c - Kernel interface for RPLD
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -52,29 +52,29 @@ static int kmd_load(void);
 static int kmd_unload(void);
 
 // Stage 2 functions
-static int kio_init(struct cdev *, struct tty *);
-static int kio_open(struct cdev *, struct tty *);
-static int kio_read(const char *, int, struct tty *);
-static int kio_write(const char *, int, struct tty *);
-//static int kio_ioctl(struct tty *, u_long, void *);
-static int kio_close(struct tty *);
-static int kio_deinit(struct tty *);
+static int krpl_init(struct cdev *, struct tty *);
+static int krpl_open(struct cdev *, struct tty *);
+static int krpl_read(const char *, int, struct tty *);
+static int krpl_write(const char *, int, struct tty *);
+//static int krpl_ioctl(struct tty *, u_long, void *);
+static int krpl_close(struct tty *);
+static int krpl_deinit(struct tty *);
 
 // Stage 3 functions
-static int uio_open(struct cdev *, int, int, struct thread *);
-static int uio_read(struct cdev *, struct uio *, int);
-static int uio_ioctl(struct cdev *, u_long, caddr_t, int, struct thread *);
-static int uio_close(struct cdev *, int, int, struct thread *);
+static int urpl_open(struct cdev *, int, int, struct thread *);
+static int urpl_read(struct cdev *, struct uio *, int);
+static int urpl_ioctl(struct cdev *, u_long, caddr_t, int, struct thread *);
+static int urpl_close(struct cdev *, int, int, struct thread *);
 
 // Local functions
-inline static ssize_t avail_R(void);
-inline static ssize_t avail_W(void);
-inline static void fill_time(struct timeval *);
-inline static unsigned int min_uint(unsigned int, unsigned int);
-inline static uint32_t mkdev_26(unsigned long, unsigned long);
+static inline ssize_t avail_R(void);
+static inline ssize_t avail_W(void);
+static inline void fill_time(struct timeval *);
+static inline unsigned int min_uint(unsigned int, unsigned int);
+static inline uint32_t mkdev_26(unsigned long, unsigned long);
 static int mv_buffer(struct rpldev_packet *, const void *, size_t);
-inline static void mv_buffer2(const void *, size_t);
-inline static int mv_to_user(struct uio *, size_t);
+static inline void mv_buffer2(const void *, size_t);
+static inline int mv_to_user(struct uio *, size_t);
 
 // Variables
 static MALLOC_DEFINE(Buffer_malloc, "rpldev", "rpldev ring buffer");
@@ -90,10 +90,10 @@ static struct cdevsw kmi_fops = {
     .d_version = D_VERSION,
     .d_name    = "rpldev",
     .d_maj     = MAJOR_AUTO,
-    .d_open    = uio_open,
-    .d_read    = uio_read,
-    .d_ioctl   = uio_ioctl,
-    .d_close   = uio_close,
+    .d_open    = urpl_open,
+    .d_read    = urpl_read,
+    .d_ioctl   = urpl_ioctl,
+    .d_close   = urpl_close,
 };
 static moduledata_t kmi_rpldev = {
     .name   = "rpldev",
@@ -133,7 +133,7 @@ static int kmd_unload(void) {
 }
 
 //-----------------------------------------------------------------------------
-static int kio_init(struct cdev *cd, struct tty *tty) {
+static int krpl_init(struct cdev *cd, struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
@@ -147,7 +147,7 @@ static int kio_init(struct cdev *cd, struct tty *tty) {
     return mv_buffer(&p, NULL, 0);
 }
 
-static int kio_open(struct cdev *cd, struct tty *tty) {
+static int krpl_open(struct cdev *cd, struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
@@ -161,7 +161,7 @@ static int kio_open(struct cdev *cd, struct tty *tty) {
     return mv_buffer(&p, NULL, 0);
 }
 
-static int kio_read(const char *buf, int count, struct tty *tty) {
+static int krpl_read(const char *buf, int count, struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
@@ -176,7 +176,7 @@ static int kio_read(const char *buf, int count, struct tty *tty) {
     return mv_buffer(&p, buf, count);
 }
 
-static int kio_write(const char *buf, int count, struct tty *tty) {
+static int krpl_write(const char *buf, int count, struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
@@ -192,7 +192,7 @@ static int kio_write(const char *buf, int count, struct tty *tty) {
 }
 
 /*
-static int kio_ioctl(struct tty *tty, u_long cmd, void *arg) {
+static int krpl_ioctl(struct tty *tty, u_long cmd, void *arg) {
     struct rpldev_packet p;
     uint32_t cmd32;
 
@@ -209,7 +209,7 @@ static int kio_ioctl(struct tty *tty, u_long cmd, void *arg) {
 }
 */
 
-static int kio_close(struct tty *tty) {
+static int krpl_close(struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
@@ -223,7 +223,7 @@ static int kio_close(struct tty *tty) {
     return mv_buffer(&p, NULL, 0);
 }
 
-static int kio_deinit(struct tty *tty) {
+static int krpl_deinit(struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
@@ -238,7 +238,7 @@ static int kio_deinit(struct tty *tty) {
 }
 
 //-----------------------------------------------------------------------------
-static int uio_open(struct cdev *cd, int flag, int mode, struct thread *th) {
+static int urpl_open(struct cdev *cd, int flag, int mode, struct thread *th) {
     mtx_lock(&Open_lock);
     if(Open_count) {
         mtx_unlock(&Open_lock);
@@ -257,21 +257,21 @@ static int uio_open(struct cdev *cd, int flag, int mode, struct thread *th) {
     }
 
     BufRP = BufWP = Buffer;
-    rpl_qinit   = kio_init;
-    rpl_qopen   = kio_open;
-    rpl_qread   = kio_read;
-    rpl_qwrite  = kio_write;
+    rpl_qinit   = krpl_init;
+    rpl_qopen   = krpl_open;
+    rpl_qread   = krpl_read;
+    rpl_qwrite  = krpl_write;
     /* ioctl reporting is deactivated, because 1) a _lot_ more ioctls are
     generated in *BSD compared to Linux, 2) ioctls are not yet interpreted by
     userspace apps (ttyreplay). */
-    //rpl_qioctl  = kio_ioctl;
-    rpl_qclose  = kio_close;
-    rpl_qdeinit = kio_deinit;
+    //rpl_qioctl  = krpl_ioctl;
+    rpl_qclose  = krpl_close;
+    rpl_qdeinit = krpl_deinit;
     mtx_unlock(&Buffer_lock);
     return 0;
 }
 
-static int uio_read(struct cdev *cd, struct uio *uio, int flags) {
+static int urpl_read(struct cdev *cd, struct uio *uio, int flags) {
     size_t count;
     int eax;
 
@@ -291,7 +291,7 @@ static int uio_read(struct cdev *cd, struct uio *uio, int flags) {
     return eax;
 }
 
-static int uio_ioctl(struct cdev *cd, u_long cmd, caddr_t data, int flags,
+static int urpl_ioctl(struct cdev *cd, u_long cmd, caddr_t data, int flags,
  struct thread *th)
 {
     /* Gah, it does not even support multiple return values >:-( so I need to
@@ -333,7 +333,7 @@ static int uio_ioctl(struct cdev *cd, u_long cmd, caddr_t data, int flags,
     return ENOTTY;
 }
 
-static int uio_close(struct cdev *cd, int flags, int fmt, struct thread *th) {
+static int urpl_close(struct cdev *cd, int flags, int fmt, struct thread *th) {
     rpl_qinit   = NULL;
     rpl_qopen   = NULL;
     rpl_qread   = NULL;
@@ -350,17 +350,17 @@ static int uio_close(struct cdev *cd, int flags, int fmt, struct thread *th) {
 }
 
 //-----------------------------------------------------------------------------
-inline static ssize_t avail_R(void) {
+static inline ssize_t avail_R(void) {
     if(BufWP >= BufRP) { return BufWP - BufRP; }
     return BufWP + Bufsize - BufRP;
 }
 
-inline static ssize_t avail_W(void) {
+static inline ssize_t avail_W(void) {
     if(BufWP >= BufRP) { return BufRP + Bufsize - BufWP - 1; }
     return BufRP - BufWP - 1;
 }
 
-inline static void fill_time(struct timeval *tv) {
+static inline void fill_time(struct timeval *tv) {
     microtime(tv);
 
     if(sizeof(tv->tv_sec) == sizeof(uint32_t)) {
@@ -377,11 +377,11 @@ inline static void fill_time(struct timeval *tv) {
     return;
 }
 
-inline static unsigned int min_uint(unsigned int a, unsigned int b) {
+static inline unsigned int min_uint(unsigned int a, unsigned int b) {
     return a < b ? a : b;
 }
 
-inline static uint32_t mkdev_26(unsigned long maj, unsigned long min) {
+static inline uint32_t mkdev_26(unsigned long maj, unsigned long min) {
     return (maj << 20) | (min & 0xFFFFF);
 }
 
@@ -399,7 +399,7 @@ static int mv_buffer(struct rpldev_packet *p, const void *buf, size_t count) {
     return count;
 }
 
-inline static void mv_buffer2(const void *src, size_t count) {
+static inline void mv_buffer2(const void *src, size_t count) {
     size_t x = Buffer + Bufsize - BufWP;
 
     if(count < x) {
@@ -414,7 +414,7 @@ inline static void mv_buffer2(const void *src, size_t count) {
     return;
 }
 
-inline static int mv_to_user(struct uio *uio, size_t count) {
+static inline int mv_to_user(struct uio *uio, size_t count) {
     size_t x = Buffer + Bufsize - BufRP;
     int eax;
 
