@@ -16,8 +16,8 @@ include/global.h - Shared definitions for user-space apps
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -30,13 +30,17 @@ include/global.h - Shared definitions for user-space apps
 #include "rpl_endian.h"
 #include "rpl_stdint.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifndef O_BINARY
 #    define O_BINARY 0
 #endif
 #define _(s) gettext(s)
 
 #define MAXFNLEN 256
-#define TTYRPLD_VERSION "2.01"
+#define TTYRPLD_VERSION "2.02"
 #if defined(__FreeBSD__) || defined(__OpenBSD__)
 #    define D_IOCTL(fd, cmd, eax) (ioctl((fd), (cmd), &(eax)) == 0)
 #else
@@ -49,10 +53,14 @@ extern ssize_t read_wait(int, void *, size_t);
 extern off_t G_skip(int, off_t, int);
 extern void swab_be(void *, size_t);
 
-inline static unsigned int min_uint(unsigned int a, unsigned int b) {
-    return a < b ? a : b;
+static inline unsigned int min_uint(unsigned int a, unsigned int b) {
+    return (a < b) ? a : b;
 }
 
+#ifdef __cplusplus
+} // extern "C"
+#endif
+
 #endif // TTYRPLD_GLOBAL_H
 
 //=============================================================================
