@@ -16,8 +16,8 @@ kernel/rpldev.c - Kernel interface for RPLD
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -96,14 +96,14 @@ static unsigned int urpl_poll(struct file *, poll_table *);
 static int          urpl_close(struct inode *, struct file *);
 
 // Local functions
-inline static ssize_t avail_R(void);
-inline static ssize_t avail_W(void);
-inline static void fill_time(struct timeval *);
-inline static unsigned int min_uint(unsigned int, unsigned int);
-inline static uint32_t mkdev_26(unsigned long, unsigned long);
+static inline ssize_t avail_R(void);
+static inline ssize_t avail_W(void);
+static inline void fill_time(struct timeval *);
+static inline unsigned int min_uint(unsigned int, unsigned int);
+static inline uint32_t mkdev_26(unsigned long, unsigned long);
 static int mv_buffer(struct rpldev_packet *, const void *, size_t);
-inline static void mv_buffer2(const void *, size_t);
-inline static void mv_to_user(char __user *, size_t);
+static inline void mv_buffer2(const void *, size_t);
+static inline void mv_to_user(char __user *, size_t);
 
 // Variables
 static DECLARE_WAIT_QUEUE_HEAD(Pull_queue);
@@ -134,7 +134,7 @@ extern __exit void cleanup_module(void);
 MODULE_DESCRIPTION("ttyrpld Kernel interface");
 MODULE_AUTHOR("Jan Engelhardt <jengelh [at] linux01 gwdg de>");
 MODULE_LICENSE("GPL v2");
-MODULE_PARM_DESC(Bufsize, "Buffer size (default 64K)");
+MODULE_PARM_DESC(Bufsize, "Buffer size (default 32K)");
 MODULE_PARM_DESC(Minor_nr, "Minor number to use (default: 255(=DYNAMIC))");
 #ifdef KERNEL_2_4
 MODULE_PARM(Bufsize, "i");
@@ -152,8 +152,8 @@ __init int init_module(void) {
     if((eax = misc_register(&kmi_miscinfo)) != 0) {
         return eax;
     }
-    Minor_nr = kmi_miscinfo.minor; // give it back to sysfs
-    printk(KERN_INFO "Registered at minor %d\n", Minor_nr);
+    Minor_nr = kmi_miscinfo.minor; // give minor back to sysfs
+    printk(KERN_INFO PREFIX "registered at minor %d\n", Minor_nr);
     return 0;
 }
 
@@ -242,8 +242,8 @@ static int krpl_write(const char __user *buf, size_t count,
        hitting a key, and EVT_WRITE for the shell displaying it.
 
     2. echo mode (cat waiting for EOF on stdin)
-       The _tty driver_ echoes chars back. This generates EVT_READ for your
-       keyboard interaction, plus one EVT_WRITE when an end-of-line is
+       The _tty driver_ echoes _single_ chars back. This generates EVT_READ for
+       your keyboard interaction, plus _one_ EVT_WRITE when an end-of-line is
        received.
 
     Sounds familiar? Anyway, don't care, we log it all in userspace. You can
@@ -452,19 +452,19 @@ static int urpl_close(struct inode *inode, struct file *filp) {
 }
 
 //-----------------------------------------------------------------------------
-inline static ssize_t avail_R(void) {
+static inline ssize_t avail_R(void) {
     // Return the number of available bytes to read
     if(BufWP >= BufRP) { return BufWP - BufRP; }
     return BufWP + Bufsize - BufRP;
 }
 
-inline static ssize_t avail_W(void) {
+static inline ssize_t avail_W(void) {
     // Return the number of available bytes to write
     if(BufWP >= BufRP) { return BufRP + Bufsize - BufWP - 1; }
     return BufRP - BufWP - 1;
 }
 
-inline static void fill_time(struct timeval *tv) {
+static inline void fill_time(struct timeval *tv) {
     do_gettimeofday(tv);
 
     /* The following code all gets optimized away on LE, yay! And even on BE,
@@ -484,11 +484,11 @@ inline static void fill_time(struct timeval *tv) {
     return;
 }
 
-inline static unsigned int min_uint(unsigned int a, unsigned int b) {
+static inline unsigned int min_uint(unsigned int a, unsigned int b) {
     return a < b ? a : b;
 }
 
-inline static uint32_t mkdev_26(unsigned long maj, unsigned long min) {
+static inline uint32_t mkdev_26(unsigned long maj, unsigned long min) {
     /* Enforce the in-2.6-kernel scheme on userspace. That's because computing
     the compatibility scheme (minor:12,major:12,minor:8) takes longer to
     compute. See the optimization statement at the top. */
@@ -513,7 +513,7 @@ static int mv_buffer(struct rpldev_packet *p, const void *buf, size_t count) {
     return count;
 }
 
-inline static void mv_buffer2(const void *src, size_t count) {
+static inline void mv_buffer2(const void *src, size_t count) {
     /* This function is responsible for copying (a specific amount of
     arbitrary data) into the circulary buffer. (Taking the wrappage into
     account!) The parent function -- mv_buffer() in this case -- must make sure
@@ -532,7 +532,7 @@ inline static void mv_buffer2(const void *src, size_t count) {
     return;
 }
 
-inline static void mv_to_user(char __user *dest, size_t count) {
+static inline void mv_to_user(char __user *dest, size_t count) {
     /* mv_to_user() reads COUNT bytes from the circulary buffer and puts it
     into userspace memory. The caller must make sure that COUNT is at most
     avail_R(). */
