@@ -16,8 +16,8 @@ user/rdsh.c - Shared functions for RPLD/INFOD/RPLCTL
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -39,7 +39,7 @@ user/rdsh.c - Shared functions for RPLD/INFOD/RPLCTL
 #define KERNEL_VERSION(a, b, c) (((a) << 16) | ((b) << 8) | (c))
 
 // Functions
-inline static int K_VERSION(void);
+static inline long K_VERSION(void);
 static void setup_kversion(void);
 
 // External Variables
@@ -139,7 +139,7 @@ ssize_t send_wait(int fd, const void *buf, size_t count, int flags) {
 }
 
 //-----------------------------------------------------------------------------
-inline static int K_VERSION(void) {
+static inline long K_VERSION(void) {
     pthread_mutex_lock(&k_version_lock);
     if(k_version_data == 0) { setup_kversion(); }
     pthread_mutex_unlock(&k_version_lock);
