@@ -16,8 +16,8 @@ user/replay.c - Realtime TTY log analyzer
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -26,7 +26,6 @@ user/replay.c - Realtime TTY log analyzer
 #include <sys/types.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <popt.h>
 #include <sched.h> // sched_yield()
 #include <stdio.h>
 #include <stdlib.h>
@@ -34,6 +33,7 @@ user/replay.c - Realtime TTY log analyzer
 #include <time.h> // nsec def, nanosleep()
 #include <unistd.h>
 
+#include <libHX.h>
 #include "dev.h"
 #include "rpl_packet.h"
 #include "global.h"
@@ -76,15 +76,18 @@ static void e_proc(int, struct rpldsk_packet *, struct pctrl_info *, char *,
 static unsigned long calc_ovcorr(unsigned long, int);
 static int find_next_packet(int);
 static int get_options(int *, const char ***);
-inline static ssize_t read_nullfm(int, size_t);
+static void getopt_jump(const struct HXoptcb *);
+static void getopt_msec(const struct HXoptcb *);
+static void getopt_skip(const struct HXoptcb *);
+static inline ssize_t read_nullfm(int, size_t);
 static ssize_t read_through(int, int, size_t);
 static ssize_t read_waitfm(int, void *, size_t);
 static int seek_to_end(int);
 static int usleep_ovcorr(struct timeval *, long *);
 static void tv_delta(const struct timeval *, const struct timeval *,
  struct timeval *);
-inline static unsigned long long tv2usec(const struct timeval *);
-inline static void usec2tv(unsigned long long, struct timeval *);
+static inline unsigned long long tv2usec(const struct timeval *);
+static inline void usec2tv(unsigned long long, struct timeval *);
 
 //-----------------------------------------------------------------------------
 int main(int argc, const char **argv) {
@@ -92,7 +95,7 @@ int main(int argc, const char **argv) {
     int i;
 
     load_locale(*argv);
-    if(!get_options(&argc, &argv)) { return EXIT_FAILURE; }
+    if(get_options(&argc, &argv) <= 0) { return EXIT_FAILURE; }
 
     fprintf(stderr, "> ttyreplay " TTYRPLD_VERSION "\n");
     fprintf(stderr,
@@ -118,16 +121,16 @@ int main(int argc, const char **argv) {
     if(!Opt.no_pctrl) { pctrl_init(); }
 
     for(i = 0; i < argc; /* see switch() */) {
+        const char *file = (argv[i][0] == '-' && argv[i][1] == '\0') ?
+                           "/dev/stdin" : argv[i];
         int fd, rv;
-        if(strcmp(argv[i], "-") == 0) { argv[i] = "/dev/stdin"; }
-        if((fd = open(argv[i], O_RDONLY)) < 0) {
+        if((fd = open(file, O_RDONLY)) < 0) {
             fprintf(stderr, _("Could not open %s: %s\n"),
-              argv[i], strerror(errno));
-            ++i;
+              argv[i++], strerror(errno));
             continue;
         }
 
-        rv = replay_file(fd, argv[i]);
+        rv = replay_file(fd, file);
         close(fd);
 
         switch(rv) {
@@ -421,98 +424,66 @@ static int find_next_packet(int fd) {
 }
 
 static int get_options(int *argc, const char ***argv) {
-    static const char *_empty_argv[] = {NULL, NULL};
-    char *tmp = NULL;
-    struct poptOption options_table[] = {
-        {"no-pctrl", 0, POPT_ARG_NONE, &Opt.no_pctrl, 0,
-         _("Do not enable playing controls"), NULL},
-        {NULL, 'F', POPT_ARG_NONE, NULL, 'F',
-         _("Live feed follow mode (like `tail -f`)"), NULL},
-        {NULL, 'J', POPT_ARG_STRING, &tmp, 'J',
-         _("Seek to time position (HH:MM:SS or total SEC, "
-         "see docs)"), "tspec"},
-        {NULL, 'S', POPT_ARG_DOUBLE, &Opt.factor, '\0',
-         _("Speed factor (default: 1.0)"), NULL},
-        {NULL, 'T', POPT_ARG_NONE, &Opt.nodelay, 'T',
-         _("No delays (useful for text file grepping)"), NULL},
-        {NULL, 'f', POPT_ARG_NONE, NULL, 'f', _("Catch-up follow mode (play"
-         " file, switch to live feed on EOF)"), NULL},
-        {NULL, 'j', POPT_ARG_LONG, &Opt.skval, 'j',
-         _("Skip the given number of EVT_WRITE packets"), NULL},
-        {NULL, 'm', POPT_ARG_LONG, &Opt.maxdelay, 'm',
-         _("Maximum delay to wait between packets"), "msec"},
-        {NULL, 't', POPT_ARG_NONE, NULL, 't',
-         _("Show the timestamp at the top of the screen"), NULL},
-        POPT_AUTOHELP
-        POPT_TABLEEND
+    struct HXoption options_table[] = {
+        {.ln = "no-pctrl", .type = HXOPT_NONE, .ptr = &Opt.no_pctrl,
+         .help = _("Do not enable playing controls")},
+        {.sh = 'F', .type = HXOPT_VAL, .ptr = &Opt.follow, .val = FM_LIVE,
+         .help = _("Live feed follow mode (like `tail -f`)")},
+        {.sh = 'J', .type = HXOPT_STRING, .cb = getopt_jump,
+         .help = _("Seek to time position (HH:MM:SS or total SEC, "
+         "see docs)"), .htyp = "tspec"},
+        {.sh = 'S', .type = HXOPT_DOUBLE, .ptr = &Opt.factor,
+         .help = _("Speed factor (default: 1.0)")},
+        {.sh = 'T', .type = HXOPT_VAL, .ptr = &Opt.follow, .val = FM_NODELAY,
+         .help = _("No delays (useful for text file grepping)")},
+        {.sh = 'f', .type = HXOPT_VAL, .ptr = &Opt.follow, .val = FM_CATCHUP,
+         .help = _("Catch-up follow mode (play file, switch to live feed on EOF)")},
+        {.sh = 'j', .type = HXOPT_LONG, .ptr = &Opt.skval, .cb = getopt_skip,
+         .help = _("Skip the given number of EVT_WRITE packets")},
+        {.sh = 'm', .type = HXOPT_LONG, .cb = getopt_msec,
+         .help = _("Maximum delay to wait between packets"), .htyp = _("msec")},
+        {.sh = 't', .type = HXOPT_NONE | HXOPT_INC, .ptr = &Opt.showtime,
+         .help = _("Show the timestamp at the top of the screen")},
+        HXOPT_AUTOHELP,
+        HXOPT_TABLEEND,
     };
 
-    poptContext ctx;
-    const char **args;
-    int c, argk;
+    return HX_getopt(options_table, argc, argv, HXOPT_USAGEONERR);
+}
 
-    ctx = poptGetContext(**argv, *argc, *argv, options_table, 0);
-    while((c = poptGetNextOpt(ctx)) >= 0) {
-        switch(c) {
-            case 'F':
-                Opt.follow = FM_LIVE;
-                break;
-            case 'J': { // jump to time
-                char *sec = "", *min = "", *hr = "";
+static void getopt_jump(const struct HXoptcb *cbi) {
+    char *sec = "", *min = "", *hr = "";
+    char *tmp = HX_strdup(cbi->s), *origtmp = tmp;
 
-                Opt.sktype = PCTRL_SKTIME;
-                Opt.skval  = 0;
+    Opt.sktype = PCTRL_SKTIME;
+    Opt.skval  = 0;
 
-                if((sec = strrchr(tmp, ':')) == NULL) {
-                    sec = tmp;
-                } else {
-                    *sec++ = '\0';
-                    if((min = strrchr(tmp, ':')) == NULL) {
-                        min = tmp;
-                    } else {
-                        *min++ = '\0';
-                        hr = tmp;
-                    }
-                }
-                Opt.skval = (strtol(sec, NULL, 0) + 60 * strtol(min, NULL, 0) +
-                 3600 * strtol(hr, NULL, 0)) * 1000;
-                free(tmp);
-                break;
-            }
-            case 'T':
-                Opt.follow = FM_NODELAY;
-                break;
-            case 'f':
-                Opt.follow = FM_CATCHUP;
-                break;
-            case 'j': // jump to packet
-                Opt.sktype = PCTRL_SKPACK;
-                break;
-            case 'm': // maximum delay between two packets
-                Opt.maxdelay *= 1000;
-                break;
-            case 't': // Show timestamp
-                ++Opt.showtime;
-                break;
+    if((sec = strrchr(tmp, ':')) == NULL) {
+        sec = tmp;
+    } else {
+        *sec++ = '\0';
+        if((min = strrchr(tmp, ':')) == NULL) {
+            min = tmp;
+        } else {
+            *min++ = '\0';
+            hr = tmp;
         }
     }
 
-    if(c < -1) {
-        fprintf(stderr, "%s: %s\n", poptBadOption(ctx, 0), poptStrerror(c));
-        poptFreeContext(ctx);
-        return 0;
-    }
+    Opt.skval = (strtol(sec, NULL, 0) + 60 * strtol(min, NULL, 0) +
+     3600 * strtol(hr, NULL, 0)) * 1000;
+    free(origtmp);
+    return;
+}
 
-    if((args = poptGetArgs(ctx)) != NULL) {
-        argk = count_args(args);
-        poptDupArgv(argk, args, argc, argv);
-    } else {
-        *argc = 0;
-        *argv = _empty_argv;
-    }
+static void getopt_msec(const struct HXoptcb *cbi) {
+    Opt.maxdelay = cbi->l * 1000;
+    return;
+}
 
-    poptFreeContext(ctx);
-    return 1;
+static void getopt_skip(const struct HXoptcb *cbi) {
+    Opt.sktype = PCTRL_SKPACK;
+    return;
 }
 
 static ssize_t read_through(int in, int out, size_t count) {
@@ -532,7 +503,7 @@ static ssize_t read_through(int in, int out, size_t count) {
     return count;
 }
 
-inline static ssize_t read_nullfm(int fd, size_t count) {
+static inline ssize_t read_nullfm(int fd, size_t count) {
     return G_skip(fd, count, Opt.follow != FM_NONE &&
      Opt.follow != FM_NODELAY);
 }
@@ -630,10 +601,10 @@ static int usleep_ovcorr(struct timeval *req, long *skew) {
     int rv;
 
     /* The following if() block involves a "lot" of 64-bit calculations,
-    which take more time on 32-bit archs. Even if my current AMD runs at
-    approx. 30 billion instructions/second, it is only fair to add these few
-    nanoseconds to the skew. To be non-plus-ultra fair, they are only added if
-    we do not do an early return (case 2 & 3). */
+    which takes more time on 32-bit archs than on native 64-bit. Even if my
+    current AMD(32) runs at approx. 30 billion instructions/second, it is only
+    fair to add these few nanoseconds to the skew. To be nonplus-ultra fair,
+    they are only added if we do not do an early return (case 2 & 3). */
     gettimeofday(&start, NULL);
     req_usec = tv2usec(req);
 
@@ -699,11 +670,11 @@ static void tv_delta(const struct timeval *past, const struct timeval *now,
     return;
 }
 
-inline static unsigned long long tv2usec(const struct timeval *req) {
+static inline unsigned long long tv2usec(const struct timeval *req) {
     return req->tv_sec * MICROSECOND + req->tv_usec;
 }
 
-inline static void usec2tv(unsigned long long usec, struct timeval *req) {
+static inline void usec2tv(unsigned long long usec, struct timeval *req) {
     req->tv_sec  = usec / MICROSECOND;
     req->tv_usec = usec % MICROSECOND;
     return;
