@@ -16,8 +16,8 @@ user/rpld.c - User space daemon (filtering, etc.)
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -28,7 +28,6 @@ user/rpld.c - User space daemon (filtering, etc.)
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <popt.h>
 #include <pthread.h>
 #include <pwd.h>
 #include <signal.h>
@@ -59,7 +58,7 @@ extern int posix_memalign(void **, size_t, size_t);
 #    define S_IXUGO (S_IXUSR | S_IXGRP | S_IXOTH)
 #endif
 
-// The prototype order is the same as the function body order
+// Overview: The prototype order is the same as the function body order
 static void mainloop(int);
 
 static int packet_preprox(struct rpldev_packet *);
@@ -81,11 +80,12 @@ static void sighandler_alrm(int);
 static void sighandler_pipe(int);
 
 static int get_options(int *, const char ***);
+static void getopt_config(const struct HXoptcb *);
+static void getopt_username(const struct HXoptcb *);
 static int read_config(const char *);
 static int read_config_bp(const char *, const char *);
-static int pconfig_user(const struct shconf_opt *, const char *);
+static int rdconfig_user(const struct shconf_opt *, const char *);
 
-inline static const char *basename(const char *);
 static int find_devnode(uint32_t, char *, size_t, const char **);
 static int find_devnode_dive(uint32_t, char *, size_t, const char *);
 static char *getnamefromuid(uid_t, char *, size_t);
@@ -126,11 +126,11 @@ int main(int argc, const char **argv) {
          " read: %s\n"), strerror(errno));
     }
 
-    if(strcmp(basename(*argv), "rplctl") == 0) {
+    if(strcmp(HX_basename(*argv), "rplctl") == 0) {
         return rplctl_main(argc, argv);
     }
 
-    if(!get_options(&argc, &argv)) { return EXIT_FAILURE; }
+    if(get_options(&argc, &argv) <= 0) { return EXIT_FAILURE; }
     memset(&Stats, 0, sizeof(Stats));
 
     if(GOpt.verbose) {
@@ -231,7 +231,7 @@ static void mainloop(int fd) {
 
 //-----------------------------------------------------------------------------
 static int packet_preprox(struct rpldev_packet *packet) {
-    static unsigned long *tab[] = {
+    static unsigned long *const tab[] = {
         [EVT_INIT]   = &Stats.init,
         [EVT_OPEN]   = &Stats.open,
         [EVT_READ]   = &Stats.read,
@@ -359,7 +359,7 @@ static void log_open(struct tty *tty) {
 
     if(check_parent_directory(tty->log) <= 0) {
         notify(LOG_ERR, _("Directory permission denied: It won't be possible"
-         " to write to the file %s, expect warnings.\n"), buf);
+         " to write to the file %s, expect warnings.\n"), tty->log);
     }
 
     tty->fd = open(tty->log, O_WRONLY | O_CREAT | O_APPEND, S_IWUSR);
@@ -614,82 +614,55 @@ static void sighandler_pipe(int s) {
 
 //-----------------------------------------------------------------------------
 static int get_options(int *argc, const char ***argv) {
-    static const char *_empty_argv[] = {NULL};
-    char *tmp;
-    struct poptOption options_table[] = {
-        {NULL, 'D', POPT_ARG_STRING, &Opt.device, 0,
-         "Path to the RPL device", "file"},
-        {NULL, 'I', POPT_ARG_VAL, &Opt.infod_start, 1,
-         "Start INFOD subcomponent", NULL},
-        {NULL, 'O', POPT_ARG_STRING, &GOpt.ofmt, 0,
-         "Override OFMT variable", "string"},
-        {NULL, 'Q', POPT_ARG_NONE, NULL, 'Q',
-         "Deactivate logging, only do bytecounts", NULL},
-        {NULL, 'U', POPT_ARG_STRING, &tmp, 'U',
-         "User to change to", "user"},
-        {NULL, 'c', POPT_ARG_STRING, &tmp, 'c',
-         "Read configuration from file (on top of hardcoded conf)", "file"},
-        {NULL, 'i', POPT_ARG_VAL, &Opt.infod_start, 0,
-         "Do not start INFOD subcomponent", NULL},
-        {NULL, 's', POPT_ARG_NONE, &GOpt.syslog, 0,
-         "Print warnings/errors to syslog", NULL},
-        {NULL, 'v', POPT_ARG_NONE, &GOpt.verbose, 0,
-         "Print statistics while rpld is running (overrides -s)", NULL},
-        POPT_AUTOHELP
-        POPT_TABLEEND
+    const struct HXoption options_table[] = {
+        {.sh = 'D', .type = HXOPT_STRING, .ptr = &Opt.device,
+         .help = _("Path to the RPL device"), .htyp = _("file")},
+        {.sh = 'I', .type = HXOPT_VAL, .ptr = &Opt.infod_start, .val = 1,
+         .help = _("Start INFOD subcomponent")},
+        {.sh = 'O', .type = HXOPT_STRING, .ptr = &GOpt.ofmt,
+         .help = _("Override OFMT variable"), .htyp = _("string")},
+        {.sh = 'Q', .type = HXOPT_NONE, .ptr = &Opt.dolog, .val = 0,
+         .help = _("Deactivate logging, only do bytecounting")},
+        {.sh = 'U', .type = HXOPT_STRING, .cb = getopt_username,
+         .help = _("User to change to"), .htyp = _("user")},
+        {.sh = 'c', .type = HXOPT_STRING, .cb = getopt_config,
+         .help = _("Read configuration from file"),
+         .htyp = _("file")},
+        {.sh = 'i', .type = HXOPT_VAL, .ptr = &Opt.infod_start, .val = 0,
+         .help = _("Do not start INFOD subcomponent")},
+        {.sh = 's', .type = HXOPT_NONE, .ptr = &GOpt.syslog,
+         .help = _("Print warnings/errors to syslog")},
+        {.sh = 'v', .type = HXOPT_NONE | HXOPT_INC, .ptr = &GOpt.verbose,
+         .help = _("Print statistics while rpld is running (overrides -s)")},
+        HXOPT_AUTOHELP,
+        HXOPT_TABLEEND,
     };
 
-    poptContext ctx;
-    const char **args;
-    int c, argk;
-
-    ctx = poptGetContext(**argv, *argc, *argv, options_table, 0);
-    while((c = poptGetNextOpt(ctx)) >= 0) {
-        switch(c) {
-            case 'Q':
-                Opt.dolog = 0;
-                break;
-            case 'U':
-                if(!pconfig_user(NULL, tmp)) { return 0; }
-                free(tmp);
-                break;
-            case 'c':
-                read_config(tmp);
-                free(tmp);
-                break;
-        }
-    }
-
-    if(c < -1) {
-        fprintf(stderr, "%s: %s\n", poptBadOption(ctx, 0), poptStrerror(c));
-        poptFreeContext(ctx);
-        return 0;
-    }
-
-    if((args = poptGetArgs(ctx)) != NULL) {
-        argk = count_args(args);
-        poptDupArgv(argk, args, argc, argv);
-    } else {
-        *argc = 0;
-        *argv = _empty_argv;
-    }
-
-    poptFreeContext(ctx);
-    return 1;
+    return HX_getopt(options_table, argc, argv, HXOPT_USAGEONERR);
 }
 
+static void getopt_config(const struct HXoptcb *cbi) {
+    read_config(cbi->s);
+    return;
+}
+
+static void getopt_username(const struct HXoptcb *cbi) {
+    rdconfig_user(NULL, cbi->s);
+    return;
+}
+    
 static int read_config(const char *file) {
-    static struct shconf_opt options_table[] = {
+    static struct shconf_opt config_table[] = {
         {"DEVICE", SHCONF_STRING, &Opt.device},
         {"OFMT",   SHCONF_STRING, &GOpt.ofmt},
         {"DO_LOG", SHCONF_IBOOL,  &Opt.dolog},
-        {"USER",   SHCONF_CB,     &GOpt.user_id, pconfig_user},
+        {"USER",   SHCONF_CB,     &GOpt.user_id, rdconfig_user},
 
         {"INFOD_PORT", SHCONF_STRING, &GOpt.infod_port},
         {"START_INFOD", SHCONF_IBOOL, &Opt.infod_start},
         {NULL},
     };
-    return HX_shconfig(file, options_table);
+    return HX_shconfig(file, config_table);
 }
 
 static int read_config_bp(const char *app_path, const char *file) {
@@ -705,7 +678,7 @@ static int read_config_bp(const char *app_path, const char *file) {
     return read_config(construct);
 }
 
-static int pconfig_user(const struct shconf_opt *t, const char *val) {
+static int rdconfig_user(const struct shconf_opt *t, const char *val) {
     if((GOpt.user_id = getuidfromname(val)) < 0) {
         fprintf(stderr, _("No such user: %s\n"), val);
         exit(EXIT_FAILURE);
@@ -714,13 +687,6 @@ static int pconfig_user(const struct shconf_opt *t, const char *val) {
 }
 
 //-----------------------------------------------------------------------------
-inline static const char *basename(const char *s) {
-    // Return file component of a full-path filename
-    const char *p;
-    if((p = strrchr(s, '/')) != NULL) { return p + 1; }
-    return s;
-}
-
 static int find_devnode(uint32_t id, char *dest, size_t len,
  const char **loc_pbase)
 {
